@@ -49,18 +49,16 @@ class KernelOptimizationNewsvendor(BaseNewsvendor, DataDrivenMixin):
 
     Examples
     --------
-    >>> from ddop.datasets.load_datasets import load_data
+    >>> from ddop.datasets import load_yaz
     >>> from ddop.newsvendor import KernelOptimizationNewsvendor
     >>> from sklearn.model_selection import train_test_split
-    >>> data = load_data("yaz_steak.csv")
-    >>> X = data.iloc[:,0:24]
-    >>> Y = data.iloc[:,24]
-    >>> cu,co = 2,1
-    >>> X_train, X_test, Y_train, Y_test = train_test_split(X, Y, test_size=0.25, random_state=1)
+    >>> X, Y = load_yaz(include_prod=['STEAK'],return_X_y=True)
+    >>> cu,co = 15,10
+    >>> X_train, X_test, Y_train, Y_test = train_test_split(X, Y, test_size=0.25, shuffle=False, random_state=0)
     >>> mdl = KernelOptimizationNewsvendor(cu, co)
     >>> mdl.fit(X_train, Y_train)
     >>> mdl.score(X_test,Y_test)
-    [80.86842105]
+    TODO: ADD SCORE
     """
 
     def __init__(self, cu, co, kernel_type="gaussian", kernel_bandwidth=1):
@@ -78,7 +76,7 @@ class KernelOptimizationNewsvendor(BaseNewsvendor, DataDrivenMixin):
         ----------
         X : array-like of shape (n_samples, n_features)
             The training input samples.
-        y : array-like of shape (n_samples, n_features)
+        y : array-like of shape (n_samples, n_outputs)
             The target values.
 
         Returns
